@@ -55,6 +55,8 @@ const char *counterNames[NUM_CONV_TYPES] = {
   "driver_entry_point", // CONV_DRIVER_ENTRY_POINT
   "cpp", // CONV_CPP
   "coredump", // CONV_COREDUMP
+  "green_context", // CONV_GREEN_CONTEXT
+  "error_log", // CONV_ERROR_LOG
   "driver_interact", // CONV_DRIVER_INTERACT
   "profiler", // CONV_PROFILER
   "openGL", // CONV_OPENGL
@@ -108,6 +110,8 @@ const char *counterTypes[NUM_CONV_TYPES] = {
   "CONV_DRIVER_ENTRY_POINT",
   "CONV_CPP",
   "CONV_COREDUMP",
+  "CONV_GREEN_CONTEXT",
+  "CONV_ERROR_LOG",
   "CONV_DRIVER_INTERACT",
   "CONV_PROFILER",
   "CONV_OPENGL",
@@ -142,9 +146,11 @@ const char *apiNames[NUM_API_TYPES] = {
   "cuDNN API",
   "cuFFT API",
   "cuSPARSE API",
+  "cuSOLVER API",
   "CUB API",
   "CAFFE2 API",
-  "RTC API"
+  "RTC API",
+  "TENSOR API"
 };
 
 const char *apiTypes[NUM_API_TYPES] = {
@@ -157,8 +163,10 @@ const char *apiTypes[NUM_API_TYPES] = {
   "API_FFT",
   "API_CUB",
   "API_SPARSE",
+  "API_SOLVER",
   "API_CAFFE2",
-  "API_RTC"
+  "API_RTC",
+  "API_TENSOR"
 };
 
 namespace {
@@ -363,11 +371,16 @@ void Statistics::setActive(const std::string &name) {
 }
 
 bool Statistics::isToRoc(const hipCounter &counter) {
-  return (counter.apiType == API_BLAS || counter.apiType == API_DNN || counter.apiType == API_SPARSE || counter.apiType == API_RUNTIME || counter.apiType == API_COMPLEX) &&
-    ((TranslateToRoc && !TranslateToMIOpen && !isRocMiopenOnly(counter)) || TranslateToMIOpen);
+  return ((counter.apiType == API_BLAS || counter.apiType == API_DNN || counter.apiType == API_SPARSE || counter.apiType == API_SOLVER ||
+           counter.apiType == API_RUNTIME || counter.apiType == API_COMPLEX || counter.apiType == API_RAND) && TranslateToRoc) || 
+           isToMIOpen(counter);
 }
 
-bool Statistics::isHipExperimental(const hipCounter& counter) {
+bool Statistics::isToMIOpen(const hipCounter &counter) {
+  return counter.apiType == API_DNN && TranslateToMIOpen;
+}
+
+bool Statistics::isHipExperimental(const hipCounter &counter) {
   return HIP_EXPERIMENTAL == (counter.supportDegree & HIP_EXPERIMENTAL);
 }
 
@@ -431,19 +444,15 @@ bool Statistics::isRemoved(const hipCounter &counter) {
          ROC_REMOVED == (counter.supportDegree & ROC_REMOVED));
 }
 
-bool Statistics::isHipSupportedV2Only(const hipCounter& counter) {
+bool Statistics::isHipSupportedV2Only(const hipCounter &counter) {
   return HIP_SUPPORTED_V2_ONLY == (counter.supportDegree & HIP_SUPPORTED_V2_ONLY);
 }
 
-bool Statistics::isRocMiopenOnly(const hipCounter& counter) {
-  return ROC_MIOPEN_ONLY == (counter.supportDegree & ROC_MIOPEN_ONLY);
-}
-
-bool Statistics::isCudaOverloaded(const hipCounter& counter) {
+bool Statistics::isCudaOverloaded(const hipCounter &counter) {
   return CUDA_OVERLOADED == (counter.supportDegree & CUDA_OVERLOADED);
 }
 
-std::string Statistics::getCudaVersion(const cudaVersions& ver) {
+std::string Statistics::getCudaVersion(const cudaVersions &ver) {
   switch (ver) {
     case CUDA_0:
     default:       return "";
@@ -484,6 +493,12 @@ std::string Statistics::getCudaVersion(const cudaVersions& ver) {
     case CUDA_120: return "12.0";
     case CUDA_121: return "12.1";
     case CUDA_122: return "12.2";
+    case CUDA_123: return "12.3";
+    case CUDA_124: return "12.4";
+    case CUDA_125: return "12.5";
+    case CUDA_126: return "12.6";
+    case CUDA_128: return "12.8";
+    case CUDA_129: return "12.9";
     case CUDNN_10: return "1.0.0";
     case CUDNN_20: return "2.0.0";
     case CUDNN_30: return "3.0.0";
@@ -530,11 +545,46 @@ std::string Statistics::getCudaVersion(const cudaVersions& ver) {
     case CUDNN_893: return "8.9.3";
     case CUDNN_894: return "8.9.4";
     case CUDNN_895: return "8.9.5";
+    case CUDNN_896: return "8.9.6";
+    case CUDNN_897: return "8.9.7";
+    case CUDNN_900: return "9.0.0";
+    case CUDNN_910: return "9.1.0";
+    case CUDNN_920: return "9.2.0";
+    case CUDNN_930: return "9.3.0";
+    case CUDNN_940: return "9.4.0";
+    case CUDNN_950: return "9.5.0";
+    case CUDNN_960: return "9.6.0";
+    case CUDNN_970: return "9.7.0";
+    case CUDNN_980: return "9.8.0";
+    case CUDNN_990: return "9.9.0";
+    case CUDNN_9100: return "9.10.0";
+    case CUDNN_9110: return "9.11.0";
+    case CUTENSOR_1010: return "1.0.1.0";
+    case CUTENSOR_1100: return "1.1.0.0";
+    case CUTENSOR_1200: return "1.2.0.0";
+    case CUTENSOR_1210: return "1.2.1.0";
+    case CUTENSOR_1220: return "1.2.2.0";
+    case CUTENSOR_1300: return "1.3.0.0";
+    case CUTENSOR_1310: return "1.3.1.0";
+    case CUTENSOR_1320: return "1.3.2.0";
+    case CUTENSOR_1330: return "1.3.3.0";
+    case CUTENSOR_1400: return "1.4.0.0";
+    case CUTENSOR_1500: return "1.5.0.0";
+    case CUTENSOR_1600: return "1.6.0.0";
+    case CUTENSOR_1610: return "1.6.1.0";
+    case CUTENSOR_1620: return "1.6.2.0";
+    case CUTENSOR_1700: return "1.7.0.0";
+    case CUTENSOR_2000: return "2.0.0.0";
+    case CUTENSOR_2010: return "2.0.1.0";
+    case CUTENSOR_2020: return "2.0.2.0";
+    case CUTENSOR_2021: return "2.0.2.1";
+    case CUTENSOR_2109: return "2.1.0.9";
+    case CUTENSOR_2200: return "2.2.0.0";
   }
   return "";
 }
 
-std::string Statistics::getHipVersion(const hipVersions& ver) {
+std::string Statistics::getHipVersion(const hipVersions &ver) {
   switch (ver) {
     case HIP_0:
     default:       return "";
@@ -599,6 +649,13 @@ std::string Statistics::getHipVersion(const hipVersions& ver) {
     case HIP_5060: return "5.6.0";
     case HIP_5070: return "5.7.0";
     case HIP_6000: return "6.0.0";
+    case HIP_6002: return "6.0.2";
+    case HIP_6010: return "6.1.0";
+    case HIP_6011: return "6.1.1";
+    case HIP_6020: return "6.2.0";
+    case HIP_6030: return "6.3.0";
+    case HIP_6040: return "6.4.0";
+    case HIP_7000: return "7.0.0";
   }
   return "";
 }
